============
Installation
============

Installation from PyPI::

    $ pip install bluesky-queueserver-api

Installation from `conda-forge`::

    $ conda install bluesky-queueserver-api -c conda-forge
